import { defineConfig } from 'vite'
import { resolve } from 'path'

import vue from '@vitejs/plugin-vue'
import dts from 'vite-plugin-dts'

// https://vitejs.dev/config/
export default defineConfig(() => ({
  plugins: [
    vue(),
    dts({
      insertTypesEntry: true,
      outputDir: resolve(__dirname, 'dist/types')
    }),
  ],
  publicDir: false,
  resolve: {
    alias: {
      '?': resolve(__dirname, './test'),
      '~': resolve(__dirname, './src')
    }
  },
  css: {
    preprocessorOptions: {
      scss: {
        additionalData: `
          @import "~/styles/inc/style";
          @import "~/styles/inc/font";
          @import "~/styles/colors";
        `
      }
    }
  },
	build: {
		lib: {
		  entry: resolve(__dirname, 'src/main.ts'),
		  name: '@funkwhale/vui',
      fileName: 'vui'
		},
		rollupOptions: {
		  external: ['vue', 'vue-i18n', '@vueuse/core', 'vue-router'],
		  output: {
        exports: 'named',
        globals: {
          vue: 'Vue'
        }
		  }
		}
  },
	test: {
		globals: true,
		environment: 'jsdom',
		outputFile: 'junit.xml',
		coverage: {
			reporter: 'cobertura'
		}
	}
}))
